# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/review_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='fsai_grpc_api/protos/review_api.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%fsai_grpc_api/protos/review_api.proto\":\n$GetNextReviewImageByMissionIdRequest\x12\x12\n\nmission_id\x18\x01 \x01(\x05\"9\n%GetNextReviewImageByMissionIdResponse\x12\x10\n\x08image_id\x18\x01 \x01(\x05\x32{\n\tReviewApi\x12n\n\x1dGetNextReviewImageByMissionId\x12%.GetNextReviewImageByMissionIdRequest\x1a&.GetNextReviewImageByMissionIdResponseb\x06proto3'
)




_GETNEXTREVIEWIMAGEBYMISSIONIDREQUEST = _descriptor.Descriptor(
  name='GetNextReviewImageByMissionIdRequest',
  full_name='GetNextReviewImageByMissionIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mission_id', full_name='GetNextReviewImageByMissionIdRequest.mission_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=41,
  serialized_end=99,
)


_GETNEXTREVIEWIMAGEBYMISSIONIDRESPONSE = _descriptor.Descriptor(
  name='GetNextReviewImageByMissionIdResponse',
  full_name='GetNextReviewImageByMissionIdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='image_id', full_name='GetNextReviewImageByMissionIdResponse.image_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=101,
  serialized_end=158,
)

DESCRIPTOR.message_types_by_name['GetNextReviewImageByMissionIdRequest'] = _GETNEXTREVIEWIMAGEBYMISSIONIDREQUEST
DESCRIPTOR.message_types_by_name['GetNextReviewImageByMissionIdResponse'] = _GETNEXTREVIEWIMAGEBYMISSIONIDRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetNextReviewImageByMissionIdRequest = _reflection.GeneratedProtocolMessageType('GetNextReviewImageByMissionIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNEXTREVIEWIMAGEBYMISSIONIDREQUEST,
  '__module__' : 'fsai_grpc_api.protos.review_api_pb2'
  # @@protoc_insertion_point(class_scope:GetNextReviewImageByMissionIdRequest)
  })
_sym_db.RegisterMessage(GetNextReviewImageByMissionIdRequest)

GetNextReviewImageByMissionIdResponse = _reflection.GeneratedProtocolMessageType('GetNextReviewImageByMissionIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETNEXTREVIEWIMAGEBYMISSIONIDRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.review_api_pb2'
  # @@protoc_insertion_point(class_scope:GetNextReviewImageByMissionIdResponse)
  })
_sym_db.RegisterMessage(GetNextReviewImageByMissionIdResponse)



_REVIEWAPI = _descriptor.ServiceDescriptor(
  name='ReviewApi',
  full_name='ReviewApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=160,
  serialized_end=283,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetNextReviewImageByMissionId',
    full_name='ReviewApi.GetNextReviewImageByMissionId',
    index=0,
    containing_service=None,
    input_type=_GETNEXTREVIEWIMAGEBYMISSIONIDREQUEST,
    output_type=_GETNEXTREVIEWIMAGEBYMISSIONIDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_REVIEWAPI)

DESCRIPTOR.services_by_name['ReviewApi'] = _REVIEWAPI

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/image_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from fsai_grpc_api.protos import utils_pb2 as fsai__grpc__api_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='fsai_grpc_api/protos/image_api.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$fsai_grpc_api/protos/image_api.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a fsai_grpc_api/protos/utils.proto\"\xd0\x01\n\x05Image\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05width\x18\x03 \x01(\x05\x12\x0e\n\x06height\x18\x04 \x01(\x05\x12\x1a\n\x08geo_bbox\x18\x05 \x01(\x0b\x32\x08.GeoBbox\x12\x12\n\nfeature_id\x18\x06 \x01(\x05\x12.\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"1\n\x18\x46indOrCreateImageRequest\x12\x15\n\x05image\x18\x01 \x01(\x0b\x32\x06.Image\"T\n\x19\x46indOrCreateImageResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x15\n\x05image\x18\x02 \x01(\x0b\x32\x06.Image\",\n\x13GetImageByIdRequest\x12\x15\n\x05image\x18\x01 \x01(\x0b\x32\x06.Image\"O\n\x14GetImageByIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x15\n\x05image\x18\x02 \x01(\x0b\x32\x06.Image\"0\n\x17GetImageDataByIdRequest\x12\x15\n\x05image\x18\x01 \x01(\x0b\x32\x06.Image\"4\n\x18GetImageDataByIdResponse\x12\x18\n\x10image_data_bytes\x18\x01 \x01(\x0c\x32\xde\x01\n\x08ImageApi\x12J\n\x11\x46indOrCreateImage\x12\x19.FindOrCreateImageRequest\x1a\x1a.FindOrCreateImageResponse\x12;\n\x0cGetImageById\x12\x14.GetImageByIdRequest\x1a\x15.GetImageByIdResponse\x12I\n\x10GetImageDataById\x12\x18.GetImageDataByIdRequest\x1a\x19.GetImageDataByIdResponse0\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,fsai__grpc__api_dot_protos_dot_utils__pb2.DESCRIPTOR,])




_IMAGE = _descriptor.Descriptor(
  name='Image',
  full_name='Image',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Image.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='Image.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width', full_name='Image.width', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='Image.height', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geo_bbox', full_name='Image.geo_bbox', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_id', full_name='Image.feature_id', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='Image.created_at', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='Image.updated_at', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=108,
  serialized_end=316,
)


_FINDORCREATEIMAGEREQUEST = _descriptor.Descriptor(
  name='FindOrCreateImageRequest',
  full_name='FindOrCreateImageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='image', full_name='FindOrCreateImageRequest.image', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=318,
  serialized_end=367,
)


_FINDORCREATEIMAGERESPONSE = _descriptor.Descriptor(
  name='FindOrCreateImageResponse',
  full_name='FindOrCreateImageResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='FindOrCreateImageResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image', full_name='FindOrCreateImageResponse.image', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=369,
  serialized_end=453,
)


_GETIMAGEBYIDREQUEST = _descriptor.Descriptor(
  name='GetImageByIdRequest',
  full_name='GetImageByIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='image', full_name='GetImageByIdRequest.image', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=455,
  serialized_end=499,
)


_GETIMAGEBYIDRESPONSE = _descriptor.Descriptor(
  name='GetImageByIdResponse',
  full_name='GetImageByIdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='GetImageByIdResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image', full_name='GetImageByIdResponse.image', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=501,
  serialized_end=580,
)


_GETIMAGEDATABYIDREQUEST = _descriptor.Descriptor(
  name='GetImageDataByIdRequest',
  full_name='GetImageDataByIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='image', full_name='GetImageDataByIdRequest.image', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=582,
  serialized_end=630,
)


_GETIMAGEDATABYIDRESPONSE = _descriptor.Descriptor(
  name='GetImageDataByIdResponse',
  full_name='GetImageDataByIdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='image_data_bytes', full_name='GetImageDataByIdResponse.image_data_bytes', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=632,
  serialized_end=684,
)

_IMAGE.fields_by_name['geo_bbox'].message_type = fsai__grpc__api_dot_protos_dot_utils__pb2._GEOBBOX
_IMAGE.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_IMAGE.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_FINDORCREATEIMAGEREQUEST.fields_by_name['image'].message_type = _IMAGE
_FINDORCREATEIMAGERESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_FINDORCREATEIMAGERESPONSE.fields_by_name['image'].message_type = _IMAGE
_GETIMAGEBYIDREQUEST.fields_by_name['image'].message_type = _IMAGE
_GETIMAGEBYIDRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_GETIMAGEBYIDRESPONSE.fields_by_name['image'].message_type = _IMAGE
_GETIMAGEDATABYIDREQUEST.fields_by_name['image'].message_type = _IMAGE
DESCRIPTOR.message_types_by_name['Image'] = _IMAGE
DESCRIPTOR.message_types_by_name['FindOrCreateImageRequest'] = _FINDORCREATEIMAGEREQUEST
DESCRIPTOR.message_types_by_name['FindOrCreateImageResponse'] = _FINDORCREATEIMAGERESPONSE
DESCRIPTOR.message_types_by_name['GetImageByIdRequest'] = _GETIMAGEBYIDREQUEST
DESCRIPTOR.message_types_by_name['GetImageByIdResponse'] = _GETIMAGEBYIDRESPONSE
DESCRIPTOR.message_types_by_name['GetImageDataByIdRequest'] = _GETIMAGEDATABYIDREQUEST
DESCRIPTOR.message_types_by_name['GetImageDataByIdResponse'] = _GETIMAGEDATABYIDRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Image = _reflection.GeneratedProtocolMessageType('Image', (_message.Message,), {
  'DESCRIPTOR' : _IMAGE,
  '__module__' : 'fsai_grpc_api.protos.image_api_pb2'
  # @@protoc_insertion_point(class_scope:Image)
  })
_sym_db.RegisterMessage(Image)

FindOrCreateImageRequest = _reflection.GeneratedProtocolMessageType('FindOrCreateImageRequest', (_message.Message,), {
  'DESCRIPTOR' : _FINDORCREATEIMAGEREQUEST,
  '__module__' : 'fsai_grpc_api.protos.image_api_pb2'
  # @@protoc_insertion_point(class_scope:FindOrCreateImageRequest)
  })
_sym_db.RegisterMessage(FindOrCreateImageRequest)

FindOrCreateImageResponse = _reflection.GeneratedProtocolMessageType('FindOrCreateImageResponse', (_message.Message,), {
  'DESCRIPTOR' : _FINDORCREATEIMAGERESPONSE,
  '__module__' : 'fsai_grpc_api.protos.image_api_pb2'
  # @@protoc_insertion_point(class_scope:FindOrCreateImageResponse)
  })
_sym_db.RegisterMessage(FindOrCreateImageResponse)

GetImageByIdRequest = _reflection.GeneratedProtocolMessageType('GetImageByIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETIMAGEBYIDREQUEST,
  '__module__' : 'fsai_grpc_api.protos.image_api_pb2'
  # @@protoc_insertion_point(class_scope:GetImageByIdRequest)
  })
_sym_db.RegisterMessage(GetImageByIdRequest)

GetImageByIdResponse = _reflection.GeneratedProtocolMessageType('GetImageByIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETIMAGEBYIDRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.image_api_pb2'
  # @@protoc_insertion_point(class_scope:GetImageByIdResponse)
  })
_sym_db.RegisterMessage(GetImageByIdResponse)

GetImageDataByIdRequest = _reflection.GeneratedProtocolMessageType('GetImageDataByIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETIMAGEDATABYIDREQUEST,
  '__module__' : 'fsai_grpc_api.protos.image_api_pb2'
  # @@protoc_insertion_point(class_scope:GetImageDataByIdRequest)
  })
_sym_db.RegisterMessage(GetImageDataByIdRequest)

GetImageDataByIdResponse = _reflection.GeneratedProtocolMessageType('GetImageDataByIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETIMAGEDATABYIDRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.image_api_pb2'
  # @@protoc_insertion_point(class_scope:GetImageDataByIdResponse)
  })
_sym_db.RegisterMessage(GetImageDataByIdResponse)



_IMAGEAPI = _descriptor.ServiceDescriptor(
  name='ImageApi',
  full_name='ImageApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=687,
  serialized_end=909,
  methods=[
  _descriptor.MethodDescriptor(
    name='FindOrCreateImage',
    full_name='ImageApi.FindOrCreateImage',
    index=0,
    containing_service=None,
    input_type=_FINDORCREATEIMAGEREQUEST,
    output_type=_FINDORCREATEIMAGERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetImageById',
    full_name='ImageApi.GetImageById',
    index=1,
    containing_service=None,
    input_type=_GETIMAGEBYIDREQUEST,
    output_type=_GETIMAGEBYIDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetImageDataById',
    full_name='ImageApi.GetImageDataById',
    index=2,
    containing_service=None,
    input_type=_GETIMAGEDATABYIDREQUEST,
    output_type=_GETIMAGEDATABYIDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_IMAGEAPI)

DESCRIPTOR.services_by_name['ImageApi'] = _IMAGEAPI

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/role_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fsai_grpc_api.protos import utils_pb2 as fsai__grpc__api_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='fsai_grpc_api/protos/role_api.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#fsai_grpc_api/protos/role_api.proto\x1a fsai_grpc_api/protos/utils.proto\"1\n\x04Role\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0f\n\x07team_id\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\".\n\x17\x46indOrCreateRoleRequest\x12\x13\n\x04role\x18\x01 \x01(\x0b\x32\x05.Role\"Q\n\x18\x46indOrCreateRoleResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x13\n\x04role\x18\x02 \x01(\x0b\x32\x05.Role\"\'\n\x10ListRolesRequest\x12\x13\n\x04role\x18\x01 \x01(\x0b\x32\x05.Role\"K\n\x11ListRolesResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x14\n\x05roles\x18\x02 \x03(\x0b\x32\x05.Role2\x86\x01\n\x07RoleApi\x12G\n\x10\x46indOrCreateRole\x12\x18.FindOrCreateRoleRequest\x1a\x19.FindOrCreateRoleResponse\x12\x32\n\tListRoles\x12\x11.ListRolesRequest\x1a\x12.ListRolesResponseb\x06proto3'
  ,
  dependencies=[fsai__grpc__api_dot_protos_dot_utils__pb2.DESCRIPTOR,])




_ROLE = _descriptor.Descriptor(
  name='Role',
  full_name='Role',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Role.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='team_id', full_name='Role.team_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='Role.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=73,
  serialized_end=122,
)


_FINDORCREATEROLEREQUEST = _descriptor.Descriptor(
  name='FindOrCreateRoleRequest',
  full_name='FindOrCreateRoleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='role', full_name='FindOrCreateRoleRequest.role', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=124,
  serialized_end=170,
)


_FINDORCREATEROLERESPONSE = _descriptor.Descriptor(
  name='FindOrCreateRoleResponse',
  full_name='FindOrCreateRoleResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='FindOrCreateRoleResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role', full_name='FindOrCreateRoleResponse.role', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=172,
  serialized_end=253,
)


_LISTROLESREQUEST = _descriptor.Descriptor(
  name='ListRolesRequest',
  full_name='ListRolesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='role', full_name='ListRolesRequest.role', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=255,
  serialized_end=294,
)


_LISTROLESRESPONSE = _descriptor.Descriptor(
  name='ListRolesResponse',
  full_name='ListRolesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='ListRolesResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roles', full_name='ListRolesResponse.roles', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=296,
  serialized_end=371,
)

_FINDORCREATEROLEREQUEST.fields_by_name['role'].message_type = _ROLE
_FINDORCREATEROLERESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_FINDORCREATEROLERESPONSE.fields_by_name['role'].message_type = _ROLE
_LISTROLESREQUEST.fields_by_name['role'].message_type = _ROLE
_LISTROLESRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_LISTROLESRESPONSE.fields_by_name['roles'].message_type = _ROLE
DESCRIPTOR.message_types_by_name['Role'] = _ROLE
DESCRIPTOR.message_types_by_name['FindOrCreateRoleRequest'] = _FINDORCREATEROLEREQUEST
DESCRIPTOR.message_types_by_name['FindOrCreateRoleResponse'] = _FINDORCREATEROLERESPONSE
DESCRIPTOR.message_types_by_name['ListRolesRequest'] = _LISTROLESREQUEST
DESCRIPTOR.message_types_by_name['ListRolesResponse'] = _LISTROLESRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Role = _reflection.GeneratedProtocolMessageType('Role', (_message.Message,), {
  'DESCRIPTOR' : _ROLE,
  '__module__' : 'fsai_grpc_api.protos.role_api_pb2'
  # @@protoc_insertion_point(class_scope:Role)
  })
_sym_db.RegisterMessage(Role)

FindOrCreateRoleRequest = _reflection.GeneratedProtocolMessageType('FindOrCreateRoleRequest', (_message.Message,), {
  'DESCRIPTOR' : _FINDORCREATEROLEREQUEST,
  '__module__' : 'fsai_grpc_api.protos.role_api_pb2'
  # @@protoc_insertion_point(class_scope:FindOrCreateRoleRequest)
  })
_sym_db.RegisterMessage(FindOrCreateRoleRequest)

FindOrCreateRoleResponse = _reflection.GeneratedProtocolMessageType('FindOrCreateRoleResponse', (_message.Message,), {
  'DESCRIPTOR' : _FINDORCREATEROLERESPONSE,
  '__module__' : 'fsai_grpc_api.protos.role_api_pb2'
  # @@protoc_insertion_point(class_scope:FindOrCreateRoleResponse)
  })
_sym_db.RegisterMessage(FindOrCreateRoleResponse)

ListRolesRequest = _reflection.GeneratedProtocolMessageType('ListRolesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTROLESREQUEST,
  '__module__' : 'fsai_grpc_api.protos.role_api_pb2'
  # @@protoc_insertion_point(class_scope:ListRolesRequest)
  })
_sym_db.RegisterMessage(ListRolesRequest)

ListRolesResponse = _reflection.GeneratedProtocolMessageType('ListRolesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTROLESRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.role_api_pb2'
  # @@protoc_insertion_point(class_scope:ListRolesResponse)
  })
_sym_db.RegisterMessage(ListRolesResponse)



_ROLEAPI = _descriptor.ServiceDescriptor(
  name='RoleApi',
  full_name='RoleApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=374,
  serialized_end=508,
  methods=[
  _descriptor.MethodDescriptor(
    name='FindOrCreateRole',
    full_name='RoleApi.FindOrCreateRole',
    index=0,
    containing_service=None,
    input_type=_FINDORCREATEROLEREQUEST,
    output_type=_FINDORCREATEROLERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListRoles',
    full_name='RoleApi.ListRoles',
    index=1,
    containing_service=None,
    input_type=_LISTROLESREQUEST,
    output_type=_LISTROLESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ROLEAPI)

DESCRIPTOR.services_by_name['RoleApi'] = _ROLEAPI

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from fsai_grpc_api.protos import area_of_interest_api_pb2 as fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2


class AreaOfInterestApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.FindOrCreateAreaOfInterest = channel.unary_unary(
                '/AreaOfInterestApi/FindOrCreateAreaOfInterest',
                request_serializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.FindOrCreateAreaOfInterestRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.FindOrCreateAreaOfInterestResponse.FromString,
                )
        self.FindAreaOfInterestById = channel.unary_unary(
                '/AreaOfInterestApi/FindAreaOfInterestById',
                request_serializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.FindAreaOfInterestByIdRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.FindAreaOfInterestByIdResponse.FromString,
                )
        self.ListAreaOfInterests = channel.unary_unary(
                '/AreaOfInterestApi/ListAreaOfInterests',
                request_serializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.ListAreaOfInterestsRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.ListAreaOfInterestsResponse.FromString,
                )
        self.UpdateAreaOfInterestById = channel.unary_unary(
                '/AreaOfInterestApi/UpdateAreaOfInterestById',
                request_serializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.UpdateAreaOfInterestByIdRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.UpdateAreaOfInterestByIdResponse.FromString,
                )
        self.DeleteAreaOfInterestById = channel.unary_unary(
                '/AreaOfInterestApi/DeleteAreaOfInterestById',
                request_serializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.DeleteAreaOfInterestByIdRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.DeleteAreaOfInterestByIdResponse.FromString,
                )
        self.GetAreaOfInterestOverlapPercent = channel.unary_unary(
                '/AreaOfInterestApi/GetAreaOfInterestOverlapPercent',
                request_serializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.GetAreaOfInterestOverlapPercentRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.GetAreaOfInterestOverlapPercentResponse.FromString,
                )
        self.GetAoiKmlDataByMissionId = channel.unary_unary(
                '/AreaOfInterestApi/GetAoiKmlDataByMissionId',
                request_serializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.GetAoiKmlDataByMissionIdRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.GetAoiKmlDataByMissionIdResponse.FromString,
                )


class AreaOfInterestApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def FindOrCreateAreaOfInterest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FindAreaOfInterestById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAreaOfInterests(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAreaOfInterestById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteAreaOfInterestById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAreaOfInterestOverlapPercent(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAoiKmlDataByMissionId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AreaOfInterestApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'FindOrCreateAreaOfInterest': grpc.unary_unary_rpc_method_handler(
                    servicer.FindOrCreateAreaOfInterest,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.FindOrCreateAreaOfInterestRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.FindOrCreateAreaOfInterestResponse.SerializeToString,
            ),
            'FindAreaOfInterestById': grpc.unary_unary_rpc_method_handler(
                    servicer.FindAreaOfInterestById,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.FindAreaOfInterestByIdRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.FindAreaOfInterestByIdResponse.SerializeToString,
            ),
            'ListAreaOfInterests': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAreaOfInterests,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.ListAreaOfInterestsRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.ListAreaOfInterestsResponse.SerializeToString,
            ),
            'UpdateAreaOfInterestById': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAreaOfInterestById,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.UpdateAreaOfInterestByIdRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.UpdateAreaOfInterestByIdResponse.SerializeToString,
            ),
            'DeleteAreaOfInterestById': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteAreaOfInterestById,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.DeleteAreaOfInterestByIdRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.DeleteAreaOfInterestByIdResponse.SerializeToString,
            ),
            'GetAreaOfInterestOverlapPercent': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAreaOfInterestOverlapPercent,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.GetAreaOfInterestOverlapPercentRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.GetAreaOfInterestOverlapPercentResponse.SerializeToString,
            ),
            'GetAoiKmlDataByMissionId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAoiKmlDataByMissionId,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.GetAoiKmlDataByMissionIdRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.GetAoiKmlDataByMissionIdResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'AreaOfInterestApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AreaOfInterestApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def FindOrCreateAreaOfInterest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AreaOfInterestApi/FindOrCreateAreaOfInterest',
            fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.FindOrCreateAreaOfInterestRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.FindOrCreateAreaOfInterestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FindAreaOfInterestById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AreaOfInterestApi/FindAreaOfInterestById',
            fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.FindAreaOfInterestByIdRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.FindAreaOfInterestByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAreaOfInterests(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AreaOfInterestApi/ListAreaOfInterests',
            fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.ListAreaOfInterestsRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.ListAreaOfInterestsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAreaOfInterestById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AreaOfInterestApi/UpdateAreaOfInterestById',
            fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.UpdateAreaOfInterestByIdRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.UpdateAreaOfInterestByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteAreaOfInterestById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AreaOfInterestApi/DeleteAreaOfInterestById',
            fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.DeleteAreaOfInterestByIdRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.DeleteAreaOfInterestByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAreaOfInterestOverlapPercent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AreaOfInterestApi/GetAreaOfInterestOverlapPercent',
            fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.GetAreaOfInterestOverlapPercentRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.GetAreaOfInterestOverlapPercentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAoiKmlDataByMissionId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AreaOfInterestApi/GetAoiKmlDataByMissionId',
            fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.GetAoiKmlDataByMissionIdRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.GetAoiKmlDataByMissionIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/category_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from fsai_grpc_api.protos import utils_pb2 as fsai__grpc__api_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='fsai_grpc_api/protos/category_api.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'fsai_grpc_api/protos/category_api.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a fsai_grpc_api/protos/utils.proto\"\xfd\x01\n\x08\x43\x61tegory\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65num\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12)\n\x08includes\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x08\x65xcludes\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12.\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\".\n\x0f\x43\x61tegoryRequest\x12\x1b\n\x08\x63\x61tegory\x18\x01 \x01(\x0b\x32\t.Category\"Q\n\x10\x43\x61tegoryResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1b\n\x08\x63\x61tegory\x18\x02 \x01(\x0b\x32\t.Category\"Y\n\x16ListCategoriesResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1d\n\ncategories\x18\x02 \x03(\x0b\x32\t.Category2\x8d\x01\n\x0b\x43\x61tegoryApi\x12;\n\x14\x46indOrCreateCategory\x12\x10.CategoryRequest\x1a\x11.CategoryResponse\x12\x41\n\x0eListCategories\x12\x16.google.protobuf.Empty\x1a\x17.ListCategoriesResponseb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,fsai__grpc__api_dot_protos_dot_utils__pb2.DESCRIPTOR,])




_CATEGORY = _descriptor.Descriptor(
  name='Category',
  full_name='Category',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Category.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='Category.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enum', full_name='Category.enum', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='Category.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='includes', full_name='Category.includes', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='excludes', full_name='Category.excludes', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='Category.created_at', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='Category.updated_at', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=170,
  serialized_end=423,
)


_CATEGORYREQUEST = _descriptor.Descriptor(
  name='CategoryRequest',
  full_name='CategoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='category', full_name='CategoryRequest.category', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=425,
  serialized_end=471,
)


_CATEGORYRESPONSE = _descriptor.Descriptor(
  name='CategoryResponse',
  full_name='CategoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='CategoryResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='category', full_name='CategoryResponse.category', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=473,
  serialized_end=554,
)


_LISTCATEGORIESRESPONSE = _descriptor.Descriptor(
  name='ListCategoriesResponse',
  full_name='ListCategoriesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='ListCategoriesResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='categories', full_name='ListCategoriesResponse.categories', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=556,
  serialized_end=645,
)

_CATEGORY.fields_by_name['includes'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_CATEGORY.fields_by_name['excludes'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_CATEGORY.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CATEGORY.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CATEGORYREQUEST.fields_by_name['category'].message_type = _CATEGORY
_CATEGORYRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_CATEGORYRESPONSE.fields_by_name['category'].message_type = _CATEGORY
_LISTCATEGORIESRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_LISTCATEGORIESRESPONSE.fields_by_name['categories'].message_type = _CATEGORY
DESCRIPTOR.message_types_by_name['Category'] = _CATEGORY
DESCRIPTOR.message_types_by_name['CategoryRequest'] = _CATEGORYREQUEST
DESCRIPTOR.message_types_by_name['CategoryResponse'] = _CATEGORYRESPONSE
DESCRIPTOR.message_types_by_name['ListCategoriesResponse'] = _LISTCATEGORIESRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Category = _reflection.GeneratedProtocolMessageType('Category', (_message.Message,), {
  'DESCRIPTOR' : _CATEGORY,
  '__module__' : 'fsai_grpc_api.protos.category_api_pb2'
  # @@protoc_insertion_point(class_scope:Category)
  })
_sym_db.RegisterMessage(Category)

CategoryRequest = _reflection.GeneratedProtocolMessageType('CategoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _CATEGORYREQUEST,
  '__module__' : 'fsai_grpc_api.protos.category_api_pb2'
  # @@protoc_insertion_point(class_scope:CategoryRequest)
  })
_sym_db.RegisterMessage(CategoryRequest)

CategoryResponse = _reflection.GeneratedProtocolMessageType('CategoryResponse', (_message.Message,), {
  'DESCRIPTOR' : _CATEGORYRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.category_api_pb2'
  # @@protoc_insertion_point(class_scope:CategoryResponse)
  })
_sym_db.RegisterMessage(CategoryResponse)

ListCategoriesResponse = _reflection.GeneratedProtocolMessageType('ListCategoriesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCATEGORIESRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.category_api_pb2'
  # @@protoc_insertion_point(class_scope:ListCategoriesResponse)
  })
_sym_db.RegisterMessage(ListCategoriesResponse)



_CATEGORYAPI = _descriptor.ServiceDescriptor(
  name='CategoryApi',
  full_name='CategoryApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=648,
  serialized_end=789,
  methods=[
  _descriptor.MethodDescriptor(
    name='FindOrCreateCategory',
    full_name='CategoryApi.FindOrCreateCategory',
    index=0,
    containing_service=None,
    input_type=_CATEGORYREQUEST,
    output_type=_CATEGORYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListCategories',
    full_name='CategoryApi.ListCategories',
    index=1,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LISTCATEGORIESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CATEGORYAPI)

DESCRIPTOR.services_by_name['CategoryApi'] = _CATEGORYAPI

# @@protoc_insertion_point(module_scope)
